@@ -176,7 +176,7 @@ def get_transforms_by_status(status, period=None, locking=False, bulk_size=None,
                                                              by_substatus=by_substatus, session=session)
             if tf_ids:
                 transform2s = orm_transforms.get_transforms_by_status(status=status, period=period, locking=locking,
-                                                                      bulk_size=None, locking_for_update=True,
+                                                                      bulk_size=None, locking_for_update=False,
                                                                       to_json=to_json, transform_ids=tf_ids,
                                                                       new_poll=new_poll, update_poll=update_poll,
                                                                       by_substatus=by_substatus, session=session)
@@ -198,7 +198,7 @@ def get_transforms_by_status(status, period=None, locking=False, bulk_size=None,
                 transforms = []
         else:
             transforms = orm_transforms.get_transforms_by_status(status=status, period=period, locking=locking,
-                                                                 locking_for_update=locking,
+                                                                 locking_for_update=False,
                                                                  bulk_size=bulk_size, to_json=to_json,
                                                                  new_poll=new_poll, update_poll=update_poll,
                                                                  only_return_id=only_return_id,
